@@ -100,7 +100,7 @@ class Clip2ZeusApp(object):
 
         if self.last_check is None or now - self.last_check > self.threshold:
             try:
-                urllib2.urlopen('http://2ze.us/')
+                UrlOpener.open('http://2ze.us/')
             except (urllib2.HTTPError, urllib2.URLError):
                 self._has_connection = False
             else:
@@ -212,7 +212,7 @@ class Clip2ZeusApp(object):
 
                 try:
                     logger.info(' - %s' % url)
-                    c = urllib2.urlopen('http://2ze.us/generate/', params)
+                    c = UrlOpener.open('http://2ze.us/generate/', params)
                 except (urllib2.HTTPError, urllib2.URLError):
                     # do something?
                     update_data = False
